@@ -321,8 +321,8 @@ class DjCSS(DjTXT):
         r"</style>",
         r"[{()}]",
         r"/\*",
-        r'".+"',
-        r"'.+'",
+        r'"(?:\\.|[^\\"])*"',  # "string"
+        r"'(?:\\.|[^\\'])*'",  # 'string'
         r"[\w-]+: ",
         r";",
     ]
